====================
ilds
====================

**ilds** 是一个常用模块的集合，为了多平台，多电脑调用方便

功能模块包含:

* 获取文件md5
* 处理文件内容

安装：
-------------
pip install -U ilds


简单的例子:
-------------

.. code-block:: python

   import ilds

   from lds.file import is_file



更新日志
-------------

0.1.36
^^^^^^^^^^
* 20190124 下载 markdown 中的图片不验证 https

0.1.35
^^^^^^^^^^
* 20190121 添加 ilds.django.user.add_superuser 用来添加 django 超级用户

0.1.34
^^^^^^^^^^
* 20190121 添加 django.util.random_key 生成 Django 使用的 SECRET_KEY

0.1.33
^^^^^^^^^^
* 20190121 添加 django.util.django_setup 设置 Django 运行环境


0.1.32
^^^^^^^^^^
* 20190118 添加 save_file 保存字符内容到文件

0.1.31
^^^^^^^^^^
* 20190114 get_title_style 添加默认颜色和粗体选项

0.1.30
^^^^^^^^^^
* 20190102 html_to_md 添加按序号重命名图片文件

0.1.29
^^^^^^^^^^
* 20181228 在列表里面获取（歌曲名称）和（表演者）所在的行和列

0.1.28
^^^^^^^^^^
* 20181228 ilds.django.util.CLEAN_STR 补充一个符号（-）

0.1.27
^^^^^^^^^^
* 20181203 添加 搜索多个字段的函数

0.1.26
^^^^^^^^^^
* 添加了获取模型的字段，名字和类型的类（django.model.ModelFields）

0.1.25
^^^^^^^^^^
* 添加 确认是否修改线上数据库的函数（django.model 模块）

0.1.24
^^^^^^^^^^
* 添加 获取文件夹下的文件列表的函数

0.1.23
^^^^^^^^^^
* 添加 获取当前日期和时间的函数
* get_now 当前日期和时间
* get_now_date 当前日期
* get_now_time 当前时间

0.1.22
^^^^^^^^^^
* 添加库 lib.browsercookie 来自：https://bitbucket.org/richardpenman/browsercookie
* browsercookie 获取浏览器 cookie

0.1.21
^^^^^^^^^^
* 添加 转换 md 文件的函数（html_to_md 在 md 模块中）

0.1.20
^^^^^^^^^^
* 添加 获取文本 md5 的函数（file模块中）
* 添加 chardet 依赖

0.1.19
^^^^^^^^^^
* 添加 13 位时间截的处理

0.1.18
^^^^^^^^^^
* 添加打印文件当前信息的函数

0.1.17
^^^^^^^^^^
* 获取文件md5的时候，不转换为大写

0.1.16
^^^^^^^^^^
* 添加库 lib.hexdump 来自：https://bitbucket.org/techtonik/hexdump/
* 添加修改文件为合法文件名

0.1.15
^^^^^^^^^^
* 修复引用错误问题
* 添加修改文件为合法文件名

0.1.14
^^^^^^^^^^
* 添加 second_to_time_str 秒转为人类阅读时间

0.1.13
^^^^^^^^^^
* 20181015 更新了歌曲名和歌手的字符

0.1.12
^^^^^^^^^^
* 添加了 excel_xlsx.get_title_style （excel表头颜色）

0.1.10
^^^^^^^^^^
* 添加了几个时间相关的函数

* form_time_to_year_mon_day 解析数字形式的日期 为 year-mon-day
* date_from_str 从字符串返回日期时间对象，格式为 YYYYMMDD
* hyphenate_date 将“YYYYMMDD”格式的日期转换为“YYYY-MM-DD”格式
* DateRange 表示两个日期之间的时间间隔
* srt_subtitles_timecode 秒转换为时间字符串 01:02:03,000

0.1.9
^^^^^^^^^^
* 添加字典排序

0.1.8
^^^^^^^^^^
* excel_xlrd 添加歌曲名和歌手名中标点符号的处理

0.1.7
^^^^^^^^^^
* 将零索引列单元格引用转换为字符串。

0.1.6
^^^^^^^^^^
* django 添加 CLEAN_STR 需要清洗的字符（用在歌曲名，表演者匹配的时候）

0.1.5
^^^^^^^^^^
* 添加命令行交互提示

0.1.4
^^^^^^^^^^
* 添加 django 模型的处理

0.1.3
^^^^^^^^^^
* 修复 excel_xlsx 自动填充 0 的问题
* json 保存格式改成两个空格，减少体积

0.1.2
^^^^^^^^^^
* 添加读取excel文件(openpyxl)
* 支持读取公式

0.1.1
^^^^^^^^^^
* 添加读取excel文件


0.1.0
^^^^^^^^^^
* 导入统一修改为 ilds
* 修改说明文档为 rst 格式

0.0.9
^^^^^^^^^^
* 把安装包加入到官方的pip服务器
* 修改包名字为 ilds 因为 lds 已经被使用
* 导入还是使用 lds

0.0.7
^^^^^^^^^^
* 添加了更多文件处理函数
* 添加了更多时间处理函数
* 添加了获取ip地址的函数

0.0.5
^^^^^^^^^^
* 修正路径问题